% VELO calculates the velocity field
%	This strings create a [vx, vz] matrix containing the horizontal and
% vertical components of velocity of all grid nodes.

% String component of TEMPSPOL: a MATLAB thermal model for deep subduction
% zones including major phase transformations.
% A.M. Negredo, J.L. Valera and E. Carminati (2002)



% definitions of horizontal distances at which the velocity field definition changes
%   x0 and za are the coordinates of the corner point at which the slab turns to subduct into the
%   mantle (computed at init_velo.m)

% x2=x1-L*cot(dip)*(1-cos(dip));
% x0=x2+L*sin(dip);
% za=depth-L;

% x-coordinates of the tip of the base (x3) and top (x4) of the slab, at the present iteration.
%   and setting the old coordinates (x3old and x4old) as those computed in the previous time step
%   (or those computed at init_velo.m the initial time)
x3old=x3;
x4old=x4;
cold=c;
x3=x0+Vs*cos(dip)*time;
x4=x3-L*sin(dip);
c=za+Vs*sin(dip)*time+cot(dip)*(x0+Vs*cos(dip)*time);

% Calculating z-coordinates of the tip of the base (x3) and top (x4) of the slab, at the 
%   present iteration

z3x3=-cot(dip)*x3+c;
z3x4old=-cot(dip)*x4old+cold;

% Setting the interesting points of the grid, where the velocity field should be updated

ix4=round(x4/Dx+1);         % imin
ix3old=round(x3old/Dx+1);   % imax
jx3=round(z3x3/Dz+1);       % jmin
jx4old=round(z3x4old/Dz+1); % jmax

% Updating the velocity distribution in the dipping slab

for j=jx3:1:jx4old
    z(j)=(j-1)*Dz;
    for i=ix4:1:ix3old
        x(i)=(i-1)*Dx;
        
        % equation of the top of the slab (z2)
        z2=tan(dip)*x(i)+za+L-tan(dip)*x1;
        % equation of the front of the slab (z3)
        z3=-cot(dip)*x(i)+c;	
        z3old=-cot(dip)*x(i)+cold;	
        % equation of the base of the slab (z4)
        z4=tan(dip)*x(i)+za-tan(dip)*x0;

    	if z(j)>=z3 & z(j)<=z3old
	        if z(j)>=z4 & z(j)<=z2
                vx(i,j)=Vs*cos(dip);
                vz(i,j)=Vs*sin(dip);
	        end
	    end
    end
end

clear z2 z3 z4 z3x3;
